@@ -3,9 +3,9 @@ from pydantic import BaseModel, Field, validator, root_validator, constr, conlis
 from typing import List, Union
 from enum import Enum
 
-from honeybee_schema._base import NamedBaseModel
+from honeybee_schema._base import IDdBaseModel
 from honeybee_schema.model import Face3D, Units
-from honeybee_schema.bc import Ground, Outdoors, Adiabatic, Surface
+from honeybee_schema.boundarycondition import Ground, Outdoors, Adiabatic, Surface
 
 from .window_parameter import SingleWindow, SimpleWindowRatio, RepeatingWindowRatio, \
     RectangularWindows, DetailedWindows
@@ -25,7 +25,7 @@ class Room2DPropertiesAbridged(BaseModel):
     )
 
 
-class Room2D(NamedBaseModel):
+class Room2D(IDdBaseModel):
 
     type: constr(regex='^Room2D$') = 'Room2D'
 
@@ -102,7 +102,7 @@ class Room2D(NamedBaseModel):
 
     @root_validator
     def check_segment_count(cls, values):
-        "Ensure len of boundary_conditions, window par, shading par match sement count."
+        "Ensure len of boundary_conditions, window par, shading par match segment count."
         floor_bound = values.get('floor_boundary')
         floor_holes = values.get('floor_holes')
         bcs = values.get('boundary_conditions')
@@ -136,7 +136,7 @@ class StoryPropertiesAbridged(BaseModel):
     )
 
 
-class Story(NamedBaseModel):
+class Story(IDdBaseModel):
 
     type: constr(regex='^Story$') = 'Story'
 
@@ -176,7 +176,7 @@ class BuildingPropertiesAbridged(BaseModel):
     )
 
 
-class Building(NamedBaseModel):
+class Building(IDdBaseModel):
 
     type: constr(regex='^Building$') = 'Building'
 
@@ -206,7 +206,7 @@ class ContextShadePropertiesAbridged(BaseModel):
     )
 
 
-class ContextShade(NamedBaseModel):
+class ContextShade(IDdBaseModel):
 
     type: constr(regex='^ContextShade$') = 'ContextShade'
 
@@ -232,7 +232,7 @@ class ModelProperties(BaseModel):
     )
 
 
-class Model(NamedBaseModel):
+class Model(IDdBaseModel):
 
     type: constr(regex='^Model$') = 'Model'
 
@@ -246,13 +246,6 @@ class Model(NamedBaseModel):
         description='A list of ContextShades in the model.'
     )
 
-    north_angle: float = Field(
-        default=0,
-        ge=0,
-        lt=360,
-        description='The clockwise north direction in degrees.'
-    )
-
     units: Units = Field(
         default=Units.meters,
         description='Text indicating the units in which the model geometry exists. '
@@ -267,7 +260,7 @@ class Model(NamedBaseModel):
             'units and is used in a variety of checks and operations that can '
             'be performed on geometry, such as solving adjacency between Room2Ds. '
             'A value of 0 will result in no checks and an inability to perform '
-            'certain operations. Typical tolerances for builing geometry range '
+            'certain operations. Typical tolerances for building geometry range '
             'from 0.1 to 0.0001 depending on the units of the geometry.'
     )
 
@@ -278,7 +271,7 @@ class Model(NamedBaseModel):
             'This value is used in a variety of checks and operations that can be '
             'performed on geometry. A value of 0 will result in no checks and '
             'an inability to perform certain operations. Typical tolerances for '
-            'builing geometry are often around 1 degree.'
+            'building geometry are often around 1 degree.'
     )
 
     properties: ModelProperties = Field(
